/*
 * Copyright (C) 2006, 2007, 2008 Etersoft
 * Copyright (C) 2006, 2007, 2008 Vitaly Lipatov
 * It is licensed as Wine under LGPL license.
 * If you have any questions, please mail to wine@etersoft.ru
 */

#ifndef __WINE_ETERSOFT_H
#define __WINE_ETERSOFT_H

/* It is forbidden by makedep to include config.h in headers */
/* #include "config.h" */
#include "wine/library.h"

#ifndef WIN32_NO_STATUS
#include "wine/debug.h"
#endif

#define LIBWINEETERSOFT_SONAME "libwine-etersoft.so.1"

/* WARN is not present in server */
#ifndef WARN
#define WARN(n,n1) TRACE(stderr,n,n1)
#endif

/* TRACE is not present in loader */
#ifndef TRACE
#define TRACE(n...) do { } while(0)
#endif

/* Now we don't need #include "wine/port.h" here */
#ifndef RTLD_NOW
#define RTLD_NOW     0x002
#endif

#define LOAD_FUNCPTR(f) if((f = wine_dlsym(et_handle, #f, NULL, 0)) == NULL){WARN("Can't find symbol %s\n", #f); }
#define ETERUNI ((void*)1)

static void *et_handle = ETERUNI;

#define LOADETER_FUNC(n) \
    if (!n) { \
        if (et_handle == ETERUNI) \
            et_handle = wine_dlopen(LIBWINEETERSOFT_SONAME, RTLD_NOW, NULL, 0); \
        if (et_handle != NULL) \
            LOAD_FUNCPTR(n); \
    }

/* Proprietary Etersoft's functions pointers */
static int (*etersoft_init)(int dword_size, int file_flags, const char *text);

static char * (*etersoft_version)();

#ifdef ETERSOFT_FUNC_LICENSE
static char * (*etersoft_license)(int code);

/* get owner of the product */
#define ETERSOFT_LICENSE_OWNER    1
/* get owner company */
#define ETERSOFT_LICENSE_COMPANY  2
/* get reg num */
#define ETERSOFT_LICENSE_REGNUM   3
/* get URL for check legality */
#define ETERSOFT_LICENSE_URL      4
/* get full path to license file */
#define ETERSOFT_LICENSE_FILE     5

#endif

static int (*etersoft_is_initialize)(void);

static int (*etersoft_1version)(void);

static void (*etersoft_fixtab)(void *data, int pointer_size);

#ifdef ETERSOFT_FUNC_SHARED
static int (*etersoft_sharing_open)(const char *name, int flags, int shared, mode_t mode );

static int (*etersoft_sharing_close)(int unix_fd );

static int (*etersoft_sharing_pre)(int unix_fd, DWORD access, DWORD sharing, unsigned int * existing_access,
                          unsigned int * existing_sharing);
static void (*etersoft_sharing_post)(int unix_fd, DWORD access, unsigned int existing_access,
                           unsigned int existing_sharing);
#endif

#ifdef ETERSOFT_FUNC_COMPARE
static int   (*etersoft_force_compare_string)(DWORD lcid, DWORD style,
                          const char* str1, int len1, const char* str2, int len2);
#endif

/*
static void (*etersoft_fixsplash)(DWORD *style, DWORD f1, DWORD f2);
*/

#ifdef ETERSOFT_FUNC_DEFWND
static int (*etersoft_fixdefwnd)(UINT msg, UINT mousemove, UINT oldmsg);
#endif

#ifdef ETERSOFT_FUNC_TIMER
static int (*etersoft_fixtimer)(UINT_PTR id, UINT *timer);
#endif

#ifdef ETERSOFT_FUNC_PROTECT
static int (*etersoft_protect)(const unsigned char *buf, const char *name);
#endif

#endif
